runSimulators <- function(TSNMat, vBaits, vDeform=NULL, vStky=NULL, rateFP, rateFN, rateD, rateS, missedProt=NULL, seedIn){

    ## FIXME: Tony need to fix this
    ##data("filteredProt")
    ##test = intersect(vBaits, filteredProt)
    ##if(length(test) != 0){
    ##    stop("You have used these (sticky/companion/involved in gluconeogenesis) proteins as bait.")
    ##}
    
    ##This function sets up all the necessary hoopla so that the imputs are
    ##in the correct form to call the other simulator functions...

    ##seed so one can regenerate random things...
    set.seed(seedIn)
    tmpMatrix = TSNMat
    
    ##The TSNMat will generally include complexes of size 2 or higher...so it
    ##is necessary to re-enter the proteins that are singleton complexes (or
    ##so this is what we posit). The if statement appends rows indexed by such
    ##proteins that don't belong to any non-trivial complex.
    if (length(missedProt) != 0){

        colNames = colnames(TSNMat)
        nRows = nrow(TSNMat)
        nCols = ncol(TSNMat)
        numMissedProt = length(missedProt)
        appendMat = matrix(0, nrow = numMissedProt, ncol = nCols)

        dimnames(appendMat) <- list(missedProt, colNames)
        tmpMatrix = rbind(TSNMat, appendMat)

    }

    ##We calculate the protein-protein complex co-membership
    ##matrix using the appended TSNMat (this is going from incidence to adjacency).
    ##Because we only care about interactions or not (and not how many) we change
    ##any nonzero element to unity.
    PPIMat = tmpMatrix %*% t(tmpMatrix)
    mode(PPIMat) = "logical"
    mode(PPIMat) = "numeric"

    ##In the experiment, only the baits will be present in the rows of the PPI matrix
    ##since these are the proteins the user has preselected to conduct the experiment.
    numBaits = length(vBaits)
    exMat = PPIMat[vBaits,]
    
    ##For each bait, we call the simulator function to generate the random FP/FN errors
    ##on each row indexed by that bait.
    for (i in 1:numBaits){

        exMat = simulator(tmpMatrix, exMat, vBaits[i], rateFP, rateFN)

    }
    ##If the user enters known deformed baits, then this function calls the deformation error
    ##simulator to generate FN's due to deformation.
    if (!is.null(vDeform)){
    
        exMat = simulatorD(vDeform, rateD, TSNMat, exMat)
    }

    ##If the user enters known sticky proteins, then this function calls the sticky error
    ##simulator to generate FP's due to stickyiness. We have a small list of proteins
    ##known to be either sticky, a companion, or involved in gluconeogensis which we
    ##called filteredProt that we attach to the sticky prot list. Note that sticky
    ##proteins should not be used as baits since this is handled in the QC.


    ##vStky = c(vStky, filteredProt)
    
    if (!is.null(vStky)){

        exMat = simulatorS(vStky, rateS, exMat)
    }

    ##Each bait should always interact with itself by definition.
    diag(exMat[1:length(vBaits), 1:length(vBaits)]) = 1
    print(dim(exMat))
    rS = recordSticky(exMat, vStky, vBaits)
    #print(rS)
    if(length(rS) != 0){
        exMat = exMat[,-rS]
    }

    exMat
   

}

