\name{applyStickyError}
\alias{applyStickyError}

\title{Function that takes sticky proteins and calculates FP's}
\description{
  This function simulates False Positive (FP) observations on
  those bait proteins known to have affinity towards a large
  number of prey proteins during the AP-MS process.
}
\usage{
applyStickyError(notFoundProt, rateSticky)
}
\arguments{
  \item{notFoundProt}{A character vector of proteins that have no
    known interactions with the bait protein B.}
  \item{rateSticky}{The rate at which bait B attracts other
    proteins ands records FP observations due to its systematic
    affinity to interact with other proteins.}
}
\details{
  If there is a non-trivial number of sticky bait proteins, the function
  \code{\link{runSimulators}} calls the intermediary function
  \code{\link{simulatorS}}. This latter function controls
  \code{\link{applyStickyError}} by examining the arguments and
  parameters. For each sticky bait, \code{\link{simulatorS}} calls this
  function to generate un-natural interactions.

  This is essentially a function for recording more FP interactions
  among baits and non-prey. The function takes in a bait that is known to
  have some high level of finding prey as a result of the experimentation.

  In essence, the bait attracts and binds to other proteins with
  which it would normally not interact.


}
\value{
  The character vector, ProtInErr:

  The return value, ProtInErr, is a vector consisting of a subset of
  proteins from the set notFoundProt. This subset will be those proteins
  which form systematic FP observations for the simulation.
}

\author{T. Chiang}

\seealso{\code{\link{applyFPErrors}}, \code{\link{applyDeformationError}} }
\examples{
data(TSNMatrix)
exampleNotFoundPrey <- rownames(TSNMatrix)[1:50]
applyStickyError(exampleNotFoundPrey, 0.9)
}
\keyword{datagen}
